# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from pubsub.v2 import pubsub_pb2 as pubsub_dot_v2_dot_pubsub__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in pubsub/v2/pubsub_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PubsubStub(object):
    """Service for publishing asynchronous messages
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Publish = channel.unary_unary(
                '/nitric.proto.pubsub.v1.Pubsub/Publish',
                request_serializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishRequest.SerializeToString,
                response_deserializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishResponse.FromString,
                _registered_method=True)


class PubsubServicer(object):
    """Service for publishing asynchronous messages
    """

    def Publish(self, request, context):
        """Publishes a message to a given topic
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PubsubServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Publish': grpc.unary_unary_rpc_method_handler(
                    servicer.Publish,
                    request_deserializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishRequest.FromString,
                    response_serializer=pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nitric.proto.pubsub.v1.Pubsub', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('nitric.proto.pubsub.v1.Pubsub', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Pubsub(object):
    """Service for publishing asynchronous messages
    """

    @staticmethod
    def Publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/nitric.proto.pubsub.v1.Pubsub/Publish',
            pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishRequest.SerializeToString,
            pubsub_dot_v2_dot_pubsub__pb2.PubsubPublishResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
