# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pubsub/v2/pubsub.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'pubsub/v2/pubsub.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16pubsub/v2/pubsub.proto\x12\x16nitric.proto.pubsub.v1\"8\n\x14PubsubPublishRequest\x12\x12\n\ntopic_name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x17\n\x15PubsubPublishResponse2p\n\x06Pubsub\x12\x66\n\x07Publish\x12,.nitric.proto.pubsub.v1.PubsubPublishRequest\x1a-.nitric.proto.pubsub.v1.PubsubPublishResponseB\x9b\x01\n\x19io.nitric.proto.pubsub.v2B\x13PubsubPubsubServiceP\x01Z5github.com/nitrictech/nitric/proto/pubsub/v2;pubsubpb\xaa\x02\x16Nitric.Proto.Pubsub.v2\xca\x02\x16Nitric\\Proto\\Pubsub\\V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pubsub.v2.pubsub_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031io.nitric.proto.pubsub.v2B\023PubsubPubsubServiceP\001Z5github.com/nitrictech/nitric/proto/pubsub/v2;pubsubpb\252\002\026Nitric.Proto.Pubsub.v2\312\002\026Nitric\\Proto\\Pubsub\\V2'
  _globals['_PUBSUBPUBLISHREQUEST']._serialized_start=50
  _globals['_PUBSUBPUBLISHREQUEST']._serialized_end=106
  _globals['_PUBSUBPUBLISHRESPONSE']._serialized_start=108
  _globals['_PUBSUBPUBLISHRESPONSE']._serialized_end=131
  _globals['_PUBSUB']._serialized_start=133
  _globals['_PUBSUB']._serialized_end=245
# @@protoc_insertion_point(module_scope)
