# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: storage/v2/storage.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'storage/v2/storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18storage/v2/storage.proto\x12\x17nitric.proto.storage.v2\x1a\x1egoogle/protobuf/duration.proto\"E\n\x13StorageWriteRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\x0c\"\x16\n\x14StorageWriteResponse\"6\n\x12StorageReadRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"#\n\x13StorageReadResponse\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\"8\n\x14StorageDeleteRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x17\n\x15StorageDeleteResponse\"\xd9\x01\n\x18StoragePreSignUrlRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12N\n\toperation\x18\x03 \x01(\x0e\x32;.nitric.proto.storage.v2.StoragePreSignUrlRequest.Operation\x12)\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\" \n\tOperation\x12\x08\n\x04READ\x10\x00\x12\t\n\x05WRITE\x10\x01\"(\n\x19StoragePreSignUrlResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\">\n\x17StorageListBlobsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\"\x13\n\x04\x42lob\x12\x0b\n\x03key\x18\x01 \x01(\t\"H\n\x18StorageListBlobsResponse\x12,\n\x05\x62lobs\x18\x01 \x03(\x0b\x32\x1d.nitric.proto.storage.v2.Blob\"8\n\x14StorageExistsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\'\n\x15StorageExistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x32\x8b\x05\n\x07Storage\x12\x61\n\x04Read\x12+.nitric.proto.storage.v2.StorageReadRequest\x1a,.nitric.proto.storage.v2.StorageReadResponse\x12\x64\n\x05Write\x12,.nitric.proto.storage.v2.StorageWriteRequest\x1a-.nitric.proto.storage.v2.StorageWriteResponse\x12g\n\x06\x44\x65lete\x12-.nitric.proto.storage.v2.StorageDeleteRequest\x1a..nitric.proto.storage.v2.StorageDeleteResponse\x12s\n\nPreSignUrl\x12\x31.nitric.proto.storage.v2.StoragePreSignUrlRequest\x1a\x32.nitric.proto.storage.v2.StoragePreSignUrlResponse\x12p\n\tListBlobs\x12\x30.nitric.proto.storage.v2.StorageListBlobsRequest\x1a\x31.nitric.proto.storage.v2.StorageListBlobsResponse\x12g\n\x06\x45xists\x12-.nitric.proto.storage.v2.StorageExistsRequest\x1a..nitric.proto.storage.v2.StorageExistsResponseB\x9b\x01\n\x1aio.nitric.proto.storage.v2B\x0eStorageServiceP\x01Z7github.com/nitrictech/nitric/proto/storage/v2;storagepb\xaa\x02\x17Nitric.Proto.Storage.v2\xca\x02\x17Nitric\\Proto\\Storage\\V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'storage.v2.storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.nitric.proto.storage.v2B\016StorageServiceP\001Z7github.com/nitrictech/nitric/proto/storage/v2;storagepb\252\002\027Nitric.Proto.Storage.v2\312\002\027Nitric\\Proto\\Storage\\V2'
  _globals['_STORAGEWRITEREQUEST']._serialized_start=85
  _globals['_STORAGEWRITEREQUEST']._serialized_end=154
  _globals['_STORAGEWRITERESPONSE']._serialized_start=156
  _globals['_STORAGEWRITERESPONSE']._serialized_end=178
  _globals['_STORAGEREADREQUEST']._serialized_start=180
  _globals['_STORAGEREADREQUEST']._serialized_end=234
  _globals['_STORAGEREADRESPONSE']._serialized_start=236
  _globals['_STORAGEREADRESPONSE']._serialized_end=271
  _globals['_STORAGEDELETEREQUEST']._serialized_start=273
  _globals['_STORAGEDELETEREQUEST']._serialized_end=329
  _globals['_STORAGEDELETERESPONSE']._serialized_start=331
  _globals['_STORAGEDELETERESPONSE']._serialized_end=354
  _globals['_STORAGEPRESIGNURLREQUEST']._serialized_start=357
  _globals['_STORAGEPRESIGNURLREQUEST']._serialized_end=574
  _globals['_STORAGEPRESIGNURLREQUEST_OPERATION']._serialized_start=542
  _globals['_STORAGEPRESIGNURLREQUEST_OPERATION']._serialized_end=574
  _globals['_STORAGEPRESIGNURLRESPONSE']._serialized_start=576
  _globals['_STORAGEPRESIGNURLRESPONSE']._serialized_end=616
  _globals['_STORAGELISTBLOBSREQUEST']._serialized_start=618
  _globals['_STORAGELISTBLOBSREQUEST']._serialized_end=680
  _globals['_BLOB']._serialized_start=682
  _globals['_BLOB']._serialized_end=701
  _globals['_STORAGELISTBLOBSRESPONSE']._serialized_start=703
  _globals['_STORAGELISTBLOBSRESPONSE']._serialized_end=775
  _globals['_STORAGEEXISTSREQUEST']._serialized_start=777
  _globals['_STORAGEEXISTSREQUEST']._serialized_end=833
  _globals['_STORAGEEXISTSRESPONSE']._serialized_start=835
  _globals['_STORAGEEXISTSRESPONSE']._serialized_end=874
  _globals['_STORAGE']._serialized_start=877
  _globals['_STORAGE']._serialized_end=1528
# @@protoc_insertion_point(module_scope)
